##############################################################################
#
# VARIABLES
#

variable "name" {
  description = "the group name"
}

variable "team" {
  description = "the team the group / role belongs to"
}

variable "policies" {
  type        = "list"
  description = "A list of policies to be applied for the group"
}

variable "create_role" {
  description = "set to 1 if you want to create a role"
  default     = 0
}

variable "create_group" {
  description = "set to 1 if you want to create a group"
  default     = 0
}

variable "assume_role_policy" {
  description = "if you set create_role to 1, you have to set this as well"
  default     = ""
}

variable "prefix" {
  description = "don't change, really"
  default     = "org"
}

##############################################################################
#
# START
#

resource "aws_iam_group" "group" {
  count = "${var.create_group}"
  name  = "${var.prefix}-${var.team}-${var.name}"
  path  = "/groups/${var.team}/"
}

resource "aws_iam_group_policy_attachment" "group_policy" {
  # also tried:
  #   count      = "${var.create_group == 1 ? length(var.policies) : 0}"
  #   count      = "${var.create_group * length(var.policies)}"
  # same for everything.
  count = "${length(var.policies) * var.create_group }"

  group      = "${aws_iam_group.group.name}"
  policy_arn = "${element(var.policies, count.index)}"
}

# resource "aws_iam_role" "role" {
#   count              = "${var.create_role}"
#   name               = "${var.prefix}-${var.team}-${var.name}"
#   assume_role_policy = "${var.assume_role_policy}"
# }

# resource "aws_iam_role_policy_attachment" "role_policy" {
#   count      = "${var.create_role * length(var.policies)}"
#   role       = "${aws_iam_role.role.name}"
#   policy_arn = "${element(var.policies, count.index)}"
# }

##############################################################################
#
# START
#

output "group_arn" {
  value = "${element(concat(aws_iam_group.group.*.arn, list("")), 0)}"
}

output "group_name" {
  value = "${element(concat(aws_iam_group.group.*.name, list("")), 0)}"
}

# output "role_arn" {
#   value = "${element(concat(aws_iam_role.role.*.arn, list("")), 0)}"
# }


# output "role_name" {
#   value = "${element(concat(aws_iam_role.role.*.name, list("")), 0)}"
# }
